@@ -26,6 +26,10 @@ pub enum Error {
         full_command: String,
         source: Arc<FromUtf8Error>,
     },
+    Internal {
+        full_command: String,
+        config: Config,
+    },
 }
 
 impl Error {
@@ -35,6 +39,13 @@ impl Error {
             source: Arc::new(error),
         }
     }
+
+    pub(crate) fn internal(config: &Config) -> Error {
+        Error::Internal {
+            full_command: config.full_command(),
+            config: config.clone(),
+        }
+    }
 }
 
 #[doc(hidden)]
@@ -48,15 +59,16 @@ pub fn panic_on_error<T>(result: Result<T, Error>) -> T {
 
 impl Display for Error {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
+        use Error::*;
         match self {
-            Error::NoArgumentsGiven => write!(f, "no arguments given"),
-            Error::FileNotFoundWhenExecuting { executable, .. } => write!(
+            NoArgumentsGiven => write!(f, "no arguments given"),
+            FileNotFoundWhenExecuting { executable, .. } => write!(
                 f,
                 "File not found error when executing '{}'",
                 executable.to_string_lossy()
             ),
-            Error::CommandIoError { message, .. } => write!(f, "{}", message),
-            Error::NonZeroExitCode {
+            CommandIoError { message, .. } => write!(f, "{}", message),
+            NonZeroExitCode {
                 full_command,
                 exit_status,
             } => {
@@ -70,24 +82,35 @@ impl Display for Error {
                     write!(f, "{}:\n  exited with {}", full_command, exit_status)
                 }
             }
-            Error::InvalidUtf8ToStdout { full_command, .. } => {
+            InvalidUtf8ToStdout { full_command, .. } => {
                 write!(f, "{}:\n  invalid utf-8 written to stdout", full_command)
             }
-            Error::InvalidUtf8ToStderr { full_command, .. } => {
+            InvalidUtf8ToStderr { full_command, .. } => {
                 write!(f, "{}:\n  invalid utf-8 written to stderr", full_command)
             }
+            Internal { .. } => {
+                let snippets = vec![
+                    "Congratulations, you've found a bug in cradle! :/",
+                    "Please, open an issue on https://github.com/soenkehahn/cradle/issues",
+                    "with the following information:",
+                ];
+                writeln!(f, "{}\n{:#?}", snippets.join(" "), self)
+            }
         }
     }
 }
 
 impl std::error::Error for Error {
     fn source(&self) -> Option<&(dyn std::error::Error + 'static)> {
+        use Error::*;
         match self {
-            Error::FileNotFoundWhenExecuting { source, .. }
-            | Error::CommandIoError { source, .. } => Some(&**source),
-            Error::InvalidUtf8ToStdout { source, .. }
-            | Error::InvalidUtf8ToStderr { source, .. } => Some(&**source),
-            Error::NoArgumentsGiven | Error::NonZeroExitCode { .. } => None,
+            FileNotFoundWhenExecuting { source, .. } | CommandIoError { source, .. } => {
+                Some(&**source)
+            }
+            InvalidUtf8ToStdout { source, .. } | InvalidUtf8ToStderr { source, .. } => {
+                Some(&**source)
+            }
+            NoArgumentsGiven | NonZeroExitCode { .. } | Internal { .. } => None,
         }
     }
 }
