@@ -165,13 +165,14 @@ pub struct StdoutUntrimmed(pub String);
 impl Output for StdoutUntrimmed {
     #[doc(hidden)]
     fn configure(config: &mut Config) {
-        config.relay_stdout = false;
+        config.capture_stdout = true;
     }
 
     #[doc(hidden)]
     fn from_run_result(config: &Config, result: Result<RunResult, Error>) -> Result<Self, Error> {
         let result = result?;
-        Ok(StdoutUntrimmed(String::from_utf8(result.stdout).map_err(
+        let stdout = result.stdout.ok_or_else(|| Error::internal(config))?;
+        Ok(StdoutUntrimmed(String::from_utf8(stdout).map_err(
             |source| Error::InvalidUtf8ToStdout {
                 full_command: config.full_command(),
                 source: Arc::new(source),
@@ -203,7 +204,7 @@ pub struct Stderr(pub String);
 impl Output for Stderr {
     #[doc(hidden)]
     fn configure(config: &mut Config) {
-        config.relay_stderr = false;
+        config.capture_stderr = true;
     }
 
     #[doc(hidden)]
@@ -243,6 +244,7 @@ impl Output for Stderr {
 /// Also see the
 /// [section about error handling](index.html#error-handling) in
 /// the module documentation.
+#[derive(Debug)]
 pub struct Status(pub ExitStatus);
 
 impl Output for Status {
