@@ -313,3 +313,11 @@ mod run_interface {
         );
     }
 }
+
+#[cfg(target_os = "linux")]
+#[test]
+fn memory_test() {
+    use cradle::prelude::*;
+    cmd_unit!(%"cargo build -p memory-test --release");
+    cmd_unit!(%"cargo run -p memory-test --bin run_test");
+}
